@@ -1,3 +1,5 @@
+use v5.16;
+
 package Module::Release;
 
 =encoding utf8
@@ -22,15 +24,13 @@ use strict;
 
 use warnings;
 no warnings;
-use vars qw($VERSION);
 
-$VERSION = '2.124_02';
+our $VERSION = '2.126_01';
 
 use Carp qw(carp croak);
 use File::Basename qw(dirname);
 use File::Spec;
 use Scalar::Util qw(blessed);
-use DateTime;
 
 my %Loaded_mixins = ( );
 
@@ -472,7 +472,7 @@ sub perls {
     my $self = shift;
 
     my @perls = keys %{$self->{perls}};
-	warn "perls are [@perls]\n";
+	$self->_debug( "perls at the start [@perls]" );
 
     # Sort them
     @perls =
@@ -482,9 +482,10 @@ sub perls {
 	map  { [ $_, (m{.*/(.*)}) ] }
 	grep { -x $_ }
 	@perls;
-	warn "perls are [@perls]\n";
 
-    warn "Testing with ", scalar @perls, " versions of perl\n";
+	$self->_debug( "perls after filtering [@perls]" );
+	$self->_debug( "Testing with " . @perls . " perls" );
+
     return @perls;
     }
 
@@ -1241,9 +1242,8 @@ Changes file.
 =cut
 
 sub get_release_date {
-	my $self = shift;
-	my $dt = DateTime->now(time_zone => 'UTC');
-	return $dt->datetime . 'Z';
+	state $rc = require Time::Piece;
+	return Time::Piece->gmtime->datetime . 'Z';
 	}
 
 =item run
@@ -1427,7 +1427,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2007-2018, brian d foy C<< <bdfoy@cpan.org> >>. All rights reserved.
+Copyright © 2007-2021, brian d foy C<< <bdfoy@cpan.org> >>. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the Artistic License 2.0.
