@@ -1,16 +1,16 @@
+use v5.16;
+
 package Module::Release::PAUSE;
 
 use strict;
 use warnings;
 use Exporter qw(import);
-use vars qw($VERSION);
 
 use Carp qw(croak);
 
-our @EXPORT = qw(
-	);
+our @EXPORT = qw();
 
-$VERSION = '2.124_02';
+our $VERSION = '2.126_01';
 
 =encoding utf8
 
@@ -47,7 +47,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2007-2018, brian d foy C<< <bdfoy@cpan.org> >>. All rights reserved.
+Copyright © 2007-2021, brian d foy C<< <bdfoy@cpan.org> >>. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the Artistic License 2.0.
